@@ -388,7 +388,7 @@ test_that("CausalImpact.RunWithData.PreAndPostPeriod", {
   model.args <- list(niter = 100)
   suppressWarnings(impact <- CausalImpact(data, pre.period, post.period,
                                           model.args))
-  expect_equal(time(impact$model$bsts.model$original.series), time(data)[11:50])
+  expect_equal(time(impact$model$bsts.model$original.series), 11:50)
   # Test that only pre-period is used for model fitting
   expect_true(all(is.na(impact$model$bsts.model$original.series[11:40])))
   expect_equal(impact$series$response, zoo(data))
@@ -502,7 +502,7 @@ test_that("CausalImpact.RunWithData.ShortTimeSeries", {
   model.args <- list(niter = 100)
   suppressWarnings(impact <- CausalImpact(data, pre.period, post.period,
                                           model.args))
-  expect_equal(time(impact$model$bsts.model$original.series), time(data))
+  expect_equal(time(impact$model$bsts.model$original.series), 1:200)
   expect_equal(time(impact$series), time(data))
   CallAllS3Methods(impact)
 
@@ -569,6 +569,25 @@ test_that("CausalImpact.RunWithData.LargeIntegerInput", {
                tolerance = 0.01)
 })
 
+test_that("CausalImpact.RunWithData.MissingTimePoint", {
+  set.seed(1)
+  series <- zoo(data.frame(y = rnorm(20), x = rnorm(20)),
+                seq.Date(as.Date("2017-01-01"), by = 1, length.out = 20))
+  pre.period <- as.Date(c("2017-01-01", "2017-01-15"))
+  post.period <- as.Date(c("2017-01-16", "2017-01-20"))
+  model.args <- list(niter = 100)
+
+  # Missing in pre-period
+  impact <- CausalImpact(series[-10, ], pre.period, post.period, model.args)
+  indices <- time(impact$series)
+  expect_equal(indices, time(series)[-10])
+
+  # Missing in post-period
+  impact <- CausalImpact(series[-17, ], pre.period, post.period, model.args)
+  indices <- time(impact$series)
+  expect_equal(indices, time(series)[-17])
+})
+
 test_that("CausalImpact.RunWithBstsModel", {
 
   # Test on a healthy bsts object
@@ -655,6 +674,24 @@ test_that("CausalImpact.RunWithBstsModel", {
   }))
 })
 
+test_that("CausalImpact.RunWithMaxFlips", {
+
+  max.flips <- 10
+
+  # Create a dataset that with 200 columns/controls
+  data <- data.frame(matrix(rnorm(200 * 200), ncol = 200))
+
+  set.seed(1)
+  pre.period <- c(1, 100)
+  post.period <- c(101, 200)
+  model.args <- list(niter = 100, max.flips = max.flips)
+
+  suppressWarnings(impact <- CausalImpact(data, pre.period, post.period,
+                                          model.args))
+
+  expect_equal(impact$model$bsts.model$prior$max.flips, max.flips)
+})
+
 test_that("PrintSummary", {
   PrintSummary <- CausalImpact:::PrintSummary
 
